:: GsplitPortable.bat - This script will split a large file into chunks using portable Gsplit
:: Usage: GsplitPortable.bat "<inputfilespec>" "<outputFolder>" Note the output folder should NOT have a trailing /
:: There is a package of file dependencies that accompany this script including portable gsplit and the size script
:: 3-09-2010 - MDR - Dr.Backup
:: 1-2-2012 - MDR - Updated minfilesize to 300MB, added "touch" code to update MDT for small files.
:: 10-21-2013 - MDR - Minor modification to REMOVE all parts of split doesn't run to completion with success status code
:: 13-31-2017 - MDR - Improve error handling for non-existant file
:: 11-28-2017 - Detect and warn if file being split is stale
:: 01-07-2020 - Gsplit in silent (daemon) mode
:: 11-09-2020 - Handle files with embedded & in filepath

:: Customization parameters which can be adjusted
SET MIN_FILE_SIZE="300000000"
SET CHUNK_SIZE="250"
SET CHUNK_UNITS="MB"

:: Do not change anything below this line
:: Extract the parameter information to setup for copy
SET SOURCE_DRIVE_LETTER=%~d1
SET "SOURCE_RELATIVE_PATH=%~pnx1"
SET DESTINATION_PATH=%2
SET FILE_TO_COPY=%~nx1

:: Little housekeeping here to get rid of any previously generated gsplit files in this folder
:: We had to remove the quote marks from the original path argument if they were present
DEL /Q "%DESTINATION_PATH:"=%\GS-*.*"

:: If the file itself is not big enough, it cannot be split. Let's test first.
:: Reason we test is the gsplit will hang if fed too small a file :-(
:: Use a small shell script to do the file size testing. Included in package

START /w cscript "%~dp0Size.vbs" "%SOURCE_DRIVE_LETTER%%SOURCE_RELATIVE_PATH%" ">" %MIN_FILE_SIZE%
:: Return 0 = file big enough to split
IF NOT ERRORLEVEL 1 GOTO RUNGSPLIT

:: Return 1 = file not big enough to split
IF NOT ERRORLEVEL 2 GOTO TOOSMALL

:: Return 2 = file OK to split, but may be stale - WARN
IF NOT ERRORLEVEL 3 GOTO WARNSTALE

:: File does not exist
ECHO VSSGSPLITERROR-%FILE_TO_COPY%(GsplitError) > "%DESTINATION_PATH:"=%\GS-##VSSGSPLITERROR##.TXT"
GOTO EOF
:TOOSMALL


:: We are here because the file is too small to split. Let's just copy the file anyway
COPY /Y "%SOURCE_DRIVE_LETTER%%SOURCE_RELATIVE_PATH%" "%DESTINATION_PATH:"=%\GS-%FILE_TO_COPY%"
cd /d "%DESTINATION_PATH:"=%"
COPY /B "%DESTINATION_PATH:"=%\GS-%FILE_TO_COPY%" +,,
GOTO :EOF


:: Possible stale file. Warn here before splitting
:WARNSTALE
ECHO VSSGSPLITSTALEWARNING-%FILE_TO_COPY%(GsplitStaleWarning) > "%DESTINATION_PATH:"=%\GS-##VSSGSPLITWARNSTALE##.TXT"

:: Well we really do have a big file to split. Let's break it up into 250MB chunks
:RUNGSPLIT

:: Write out the gsplit.gsf configuration file that tells portable gsplit what to do
Echo [MAIN]> "%~dp0gsplit.gsf"
:: Echo Source=%SOURCE_DRIVE_LETTER%%SOURCE_RELATIVE_PATH%>> "%~dp0gsplit.gsf" --old
::11/09/2020 - quote input string to handle embedded &. Cannot use -s mode due to quote parsing around string in .gsf file
Echo|set /p="Source=%FREE_DRIVE_LETTER%%SOURCE_RELATIVE_PATH%">> "%~dp0gsplit.gsf"
Echo. >>"%~dp0gsplit.gsf"
Echo DestFolder=%DESTINATION_PATH:"=%>> "%~dp0gsplit.gsf"
Echo PieSize=%CHUNK_SIZE:"=% >> "%~dp0gsplit.gsf"
Echo PieSizeUnit=%CHUNK_UNITS:"=% >> "%~dp0gsplit.gsf"
Echo PieMask=GS-{ofw}.{oru} >> "%~dp0gsplit.gsf"
Echo SplitMethod=0 >> "%~dp0gsplit.gsf"
Echo TypePieSpanned=0 >> "%~dp0gsplit.gsf"
Echo Title=Gsplit-Backup >> "%~dp0gsplit.gsf"

:: Now that everything is setup, we can use the portable gsplit utility
"%~dp0gsplit.exe" "no" "-b-i-t-s" "%~dp0gsplit.gsf"

:: Test for gsplit error here and write out sentinel file if needed
IF %ERRORLEVEL% EQU 0 GOTO :EOF 
DEL /Q "%DESTINATION_PATH:"=%\GS-*.*"
ECHO VSSGSPLITERROR-%FILE_TO_COPY%(GsplitError) > "%DESTINATION_PATH:"=%\GS-##VSSGSPLITERROR##.TXT"

:EOF
:: All done here